package com.fjhx.purchase.service.purchase.impl;

import cn.hutool.extra.spring.SpringUtil;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.fjhx.purchase.entity.purchase.enums.PurchaseStatusEnum;
import com.fjhx.purchase.entity.purchase.po.Purchase;
import com.fjhx.purchase.entity.purchase.po.PurchaseDetail;
import com.fjhx.purchase.mapper.purchase.PurchaseMapper;
import com.fjhx.purchase.service.purchase.PurchaseDetailService;
import com.fjhx.purchase.service.purchase.PurchaseService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.purchase.util.code.CodeEnum;
import io.seata.spring.annotation.GlobalTransactional;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.purchase.entity.purchase.vo.PurchaseVo;
import com.fjhx.purchase.entity.purchase.dto.PurchaseSelectDto;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.fjhx.purchase.entity.purchase.dto.PurchaseDto;
import cn.hutool.core.bean.BeanUtil;


/**
 * <p>
 * 采购 服务实现类
 * </p>
 *
 * @author 
 * @since 2023-04-06
 */
@Service
public class PurchaseServiceImpl extends ServiceImpl<PurchaseMapper, Purchase> implements PurchaseService {

    @Override
    public Page<PurchaseVo> getPage(PurchaseSelectDto dto) {
        IWrapper<Purchase> wrapper = getWrapper();
        wrapper.orderByDesc("p", Purchase::getId);
        Page<PurchaseVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    /**
     * 详情
     * @param id
     * @return
     */
    @Override
    public PurchaseVo detail(Long id) {
        Purchase Purchase = this.getById(id);
        PurchaseVo result = BeanUtil.toBean(Purchase, PurchaseVo.class);
        return result;
    }

    /**
     * 采购新增
     * @param purchase
     */
    @Override
    public void add(Purchase purchase) {
        PurchaseService purchaseService = SpringUtil.getBean(PurchaseService.class);
        PurchaseDetailService purchaseDetailService = SpringUtil.getBean(PurchaseDetailService.class);
        purchase.setCode(CodeEnum.PURCHASE.getCode());
        purchase.setPurchaseStatus(PurchaseStatusEnum.UNDER_REVIEW.getKey());
        purchaseService.save(purchase);
        if(CollectionUtils.isNotEmpty(purchase.getPurchaseDetailList())){
            for(PurchaseDetail s : purchase.getPurchaseDetailList()){
                s.setPurchaseId(purchase.getId());
            }
            purchaseDetailService.saveBatch(purchase.getPurchaseDetailList());
        }
    }

    @Override
    public void edit(PurchaseDto purchaseDto) {
        this.updateById(purchaseDto);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

}
